    Info<< "Reading field pd\n" << endl;
    volScalarField pd
    (
        IOobject
        (
            "pd",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

    Info<< "Reading field gamma\n" << endl;
    volScalarField gamma
    (
        IOobject
        (
            "gamma",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

    Info<< "Reading field U\n" << endl;
    volVectorField U
    (
        IOobject
        (
            "U",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

#   include "createPhi.H"


    Info<< "Reading EHDtransportProperties\n" << endl;
    EHDtwoPhaseMixture EHDtwoPhaseProperties(U, phi, "gamma");

    const dimensionedScalar& rho1 = EHDtwoPhaseProperties.rho1();
    const dimensionedScalar& rho2 = EHDtwoPhaseProperties.rho2();

    const dimensionedScalar& sgm1 = EHDtwoPhaseProperties.sgm1();
    const dimensionedScalar& sgm2 = EHDtwoPhaseProperties.sgm2();

    const dimensionedScalar& eps1 = EHDtwoPhaseProperties.eps1();
    const dimensionedScalar& eps2 = EHDtwoPhaseProperties.eps2();

    // Need to store rho for ddt(rho, U)
    volScalarField rho
    (
        IOobject
        (
            "rho",
            runTime.timeName(),
            mesh,
            IOobject::READ_IF_PRESENT
        ),
        gamma*rho1 + (scalar(1) - gamma)*rho2,
        gamma.boundaryField().types()
    );
    rho.oldTime();

    volScalarField sgm
    (
        IOobject
        (
            "sgm",
            runTime.timeName(),
            mesh,
            IOobject::READ_IF_PRESENT
        ),
        gamma*sgm1 + (scalar(1) - gamma)*sgm2,
        gamma.boundaryField().types()
    );
    sgm.oldTime();

    volScalarField eps
    (
        IOobject
        (
            "eps",
            runTime.timeName(),
            mesh,
            IOobject::READ_IF_PRESENT
        ),
        gamma*eps1 + (scalar(1) - gamma)*eps2,
        gamma.boundaryField().types()
    );
    eps.oldTime();

    // Mass flux
    // Initialisation does not matter because rhoPhi is reset after the
    // gamma solution before it is used in the U equation.
    surfaceScalarField rhoPhi
    (
        IOobject
        (
            "rho*phi",
            runTime.timeName(),
            mesh,
            IOobject::NO_READ,
            IOobject::NO_WRITE
        ),
        rho1*phi
    );

    Info<< "Reading field Electric Potential Ue\n" << endl;
    volScalarField Ue
    (
        IOobject
        (
            "Ue",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );


    Info<< "Reading field electric density rhoE\n" << endl;
    volScalarField rhoE
    (
        IOobject
        (
            "rhoE",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

/*
    Info<< "Calculating field rhoEFlux\n" << endl;
    surfaceScalarField rhoEFlux
    (
        IOobject
        (
            "rhoEFlux",
            runTime.timeName(),
            mesh,
            IOobject::NO_READ,
            IOobject::NO_WRITE
        ),
      -fvc::interpolate(sgm)*mesh.magSf()*fvc::snGrad(Ue)
    );
*/
    Info<< "Calculating field g.h\n" << endl;
    volScalarField gh("gh", g & mesh.C());
    surfaceScalarField ghf("gh", g & mesh.Cf());


    volScalarField p
    (
        IOobject
        (
            "p",
            runTime.timeName(),
            mesh,
            IOobject::NO_READ,
            IOobject::AUTO_WRITE
        ),
        pd + rho*gh
    );


    label pdRefCell = 0;
    scalar pdRefValue = 0.0;
    setRefCell(pd, mesh.solutionDict().subDict("PISO"), pdRefCell, pdRefValue);


    // Construct interface from gamma distribution
    interfaceProperties interface(gamma, U, EHDtwoPhaseProperties);
